# Title of Dataset
---

Give a brief summary of dataset contents, contextualized in experimental procedures and results.


## Description of the data and file structure

These two datasets (provided in csv format, comma-separated with "." as decimal separator) are the basis for the paper "Exotic tree species have consistently lower herbivore load in a cross-Atlantic tree biodiversity experiment" by Berthelot et al., accepted for publication in Ecology.

They are cleaned and organized on the level of individual trees. These trees are in the experimental sites IDENT-Freiburg (site=FR) and IDENT-Auclair (site=AU), which are part of the IDENT (international diversity experiment network with trees) network, which itself is a part of TreeDivNet, see here: https://treedivnet.ugent.be/ExpIDENT.html. Sampling was performed in 2018 (AU) and 2019 (FR) by Sylvie Berthelot. For further information see the paper in Ecology.

There are two data files

*datapertree.csv*
These are the data for arthropod abundances sampled with beat sheets, summed over two sampling rounds.
Short explanation of columns:
* PlotNo = ID for experimental plot (a grid of 7*7 trees) within the experimental site; not unique across the whole dataset (compare site.plot)
* TreeIDunique = ID for tree individual, uniquely identifying it for the whole dataset
* genus_tree = genus of the tree
* native_status = is the tree species "native" or "exotic" at the site
* SR = tree species richness in the plot
* TreeSpecies = a shortcut for the tree species (two-letter genus plus two-letter species), see paper for list (and a note on the identity of PIGL)
* Freq = number of arthropods sampled
* Freq_Herbivores = number herbivores sampled (a subset of Freq, using classification rules as defined in the paper)
* Freq_Suckers = number sap-sucking herbivores sampled (a subset of Freq_Herbivores, using classification rules as defined in the paper)
* Freq_Chewers.adult = number herbivores in the adult chewer guild sampled (a subset of Freq_Herbivores, using classification rules as defined in the paper)
* Freq_Chewers.larva = number herbivores in the larval chewer guild sampled (a subset of Freq_Herbivores, using classification rules as defined in the paper)
* Freq_Predators = number of arthropods sampled that are assigned to the predator guild (a subset of Freq, using classification rules as defined in the paper)
* Freq_Others = number of arthropods sampled that are assigned to the "others" guild (a subset of Freq, using classification rules as defined in the paper)
* Total_Herbivores = BE CAUTIOUS WITH THIS VARIABLE! this is Freq_Herbivores extrapolated to the whole tree crown, by dividing it by a rough estimate of how much (proportion) of the crown was covered by sampling
* site = the site, Auclair or Freiburg
* site.plot = ID for the experimental plot (identifies the plot uniquely for the whole dataset)
* phylodist = phylogenetic (cophenetic) distance in ma for the tree compared to its congener in the experiment
* mixture = an ID for the tree species mixture planted in the plot

*leafd.pertree.csv*
These are the data for leaf damage.
Short explanation of columns:
* TreeUID = ID for tree individual, uniquely identifying it for the whole dataset; (equivalent to TreeIDunique in datapertree)
* PlotID = ID for experimental plot (a grid of 7*7 trees) within the experimental site; (equivalent to PlotNo in datapertree); not unique across the whole dataset (compare site.plot)
* genus_tree = genus of the tree
* native_status = is the tree species "native" or "exotic" at the site
* SR = tree species richness in the plot
* TreeSpecies = a shortcut for the tree species (two-letter genus plus two-letter species), see paper for list (and a note on the identity of PIGL)
* ChewerDamage = average leaf damage (in %) of the chewer type across sampled leaves for the given tree 
* SkeletoniserDamage = average leaf damage (in %) of the skeletoniser type across sampled leaves for the given tree 
* MinerDamage = average leaf damage (in %) of the miner type across sampled leaves for the given tree 
* totalDamage = average leaf damage (in %) for all damage types combined across sampled leaves for the given tree (NOTE: this sums to a slightly higher value than the sum of the 3 preceding categories, because it also includes damage by other [rare] damage types not included in this dataset, which were only observed in Freiburg. See details in the paper)
* site = the site, Auclair or Freiburg
* site.plot = ID for the experimental plot (identifies the plot uniquely for the whole dataset)



## Sharing/Access information

Not applicable


## Code/Software

The code provided here is to reproduce the results of the paper "Exotic tree species have consistently lower herbivore load in a cross-Atlantic tree biodiversity experiment" by Berthelot et al., accepted for publication in Ecology

There is a single R-Code script that will load the data provided as .csv files.

*It was last run with the following versions:*
R version 4.2.2 (2022-10-31 ucrt)
Platform: x86_64-w64-mingw32/x64 (64-bit)
Running under: Windows 10 x64 (build 19044)
other attached packages:
  egg_0.4.5       gridExtra_2.3   ggeffects_1.1.4 ggplot2_3.4.0   DHARMa_0.4.6    car_3.1-1      
  carData_3.0-5   lmerTest_3.1-3  lme4_1.1-31     Matrix_1.5-1    glmmTMB_1.1.5  
